[GRASS-SVN] r71068 - grass/trunk/gui/wxpython/iimage2target

svn_grass at osgeo.org svn_grass at osgeo.org
Mon May 8 22:28:04 PDT 2017


Author: ychemin
Date: 2017-05-08 22:28:03 -0700 (Mon, 08 May 2017)
New Revision: 71068

Modified:
   grass/trunk/gui/wxpython/iimage2target/ii2t_manager.py
Log:
Replaced i.rectify with i.ortho.rectify

Modified: grass/trunk/gui/wxpython/iimage2target/ii2t_manager.py
===================================================================
--- grass/trunk/gui/wxpython/iimage2target/ii2t_manager.py	2017-05-08 21:25:09 UTC (rev 71067)
+++ grass/trunk/gui/wxpython/iimage2target/ii2t_manager.py	2017-05-09 05:28:03 UTC (rev 71068)
@@ -165,6 +165,9 @@
         self.source_gisrc = ''
         self.src_maps = []
 
+        # Raster map with camera angle relative to ground surface (i.ortho.rectify)
+        self.cam_angle = ''
+
         #
         # define wizard pages
         #
@@ -940,7 +943,7 @@
 class GCP(MapFrame, ColumnSorterMixin):
     """
     Manages ground control points for georectifying. Calculates RMS statistics.
     Calls i.rectify or v.rectify to georectify map.
     """
 
     def __init__(self, parent, giface, grwiz=None, id=wx.ID_ANY,
@@ -1639,7 +1642,7 @@
 
     def OnGeorect(self, event):
         """
-        Georectifies map(s) in group using i.rectify or v.transform
+        Georectifies map(s) in group using i.ortho.rectify or v.rectify
         """
         global maptype
         self.SaveGCPs(None)
@@ -1659,14 +1662,14 @@
                                parent=self)
             wx.Yield()
 
-            ret, msg = RunCommand('i.rectify',
+            ret, msg = RunCommand('i.ortho.rectify',
                                   parent=self,
                                   getErrorMsg=True,
                                   quiet=True,
                                   group=self.xygroup,
                                   extension=self.extension,
-                                  order=self.gr_order,
                                   method=self.gr_method,
+                                  angle=self.cam_angle,
                                   flags=flags)
 
             busy.Destroy()
@@ -940,7 +943,7 @@
     """
     Manages ground control points for georectifying. Calculates RMS statistics.
-    Calls i.rectify or v.rectify to georectify map.
+    Calls i.ortho.rectify or v.rectify to georectify map.
     """
 



More information about the grass-commit mailing list